@@ -3,6 +3,6 @@ from func_returns_fwrap import *
 def test_rets():
     u'''
     >>> test_rets()
-    True
+    (True, ('k',))
     '''
-    return ((1,) == lgcl_ret() and ('k',) == char_ret())
+    return (bool(lgcl_ret()[0]), char_ret())
