@@ -4,20 +4,28 @@ import numpy as np
 N = 5
 
 def test_D1():
-    # '''
-    # >>> test_D1()
-    # '''
+    '''
+    >>> test_D1()
+    True
+    '''
     a = np.zeros((N,), dtype=np.bool_)
+    acpy = a.copy()
+    acpy[...] = True
+    acpy[::2] = False
     ar, = d1(a)
-    print ar
+    return np.all(ar.astype(bool) == acpy)
 
 def test_D2():
-    # '''
-    # >>> test_D2()
-    # '''
+    '''
+    >>> test_D2()
+    True
+    '''
     a = np.zeros((N,N), dtype=np.bool_)
+    acpy = a.copy()
+    acpy[...] = True
+    acpy[::2, ::2] = False
     ar, = d2(a)
-    print ar
+    return np.all(ar.astype(bool) == acpy)
 
 def test_D3():
     '''
@@ -29,6 +37,4 @@ def test_D3():
     acpy[...] = True
     acpy[::2,:,:] = False
     ar, = d3(a)
-    print np.all(ar == acpy)
-    # print "acpy", acpy
-    # print "ar", ar
+    return np.all(ar.astype(bool) == acpy.astype(bool))
